==> gitlab-tools-v0.2.0.tar.gz: gitlab-tools/README.md <==
gitlab-tools
============

Administration tool set for **GitLab**.

Installation notes
------------------

* `pip3` is required to install `python-gitlab`: installer will try to install `python3-pip` and `python-gitlab`.
* `curl` and `jq` are required, installer will try to install then if they are missing.

To clone this repository you need to use:

```bash
git clone --recurse-submodules https://git.cclaude.rocks/tools/gitlab-tools.git
```

You migth need to install `git`. This can be done using something like:

```bash
sudo apt install -y git
```


Installation
------------

```bash
sudo -H bash ./gitlab-tools-install.sh
```

To remove, use:

```bash
sudo bash /usr/local/share/gitlab-tools/gitlab-tools-remove.sh
```

### Install options

You can get help using :

```bash
./gitlab-tools-install.sh --help
```

| Option                            | Description                   |
|-----------------------------------|-------------------------------|
| -S, --skip-update                 | To skip update before install required packets |
| -P PMEXE, --package-manager PMEXE | Force package manger |

Warning:

`sudo -H` may be required by pip (python).


Tools list
----------

Raw commands based on **GitLab-Bash-API**.

| Command       | Description |
|---------------|-------------|
| `gl-delete`   | Perform a DELETE HTTP request |
| `gl-get`      | Perform a GET HTTP request |
| `gl-post`     | Perform a POST HTTP request |
| `gl-put`      | Perform a PUT HTTP request |

Basic commands based on **python-gitlab**.

| Command         | Description |
|-----------------|-------------|
| `glt-branch`    | Allow to manage and display gitlab branches. |
| `glt-group`     | Allow to manage and display gitlab groups. |
| `glt-project`   | Allow to manage and display gitlab project. |
| `glt-user`      | Allow to manage and display gitlab users. |

More specifics commands based on **GitLab-Bash-API** and **python-gitlab**.

| Command                                      | Description |
|----------------------------------------------|-------------|
| `glx-audit`                                  | Allow to make audit of your GitLab .|
| `glx-clone`                                  | Allow to `git clone` a set of projects. |
| `glx-find-wrong-remote-urls`                 | |
| `glx-projects-archived`                      | |
| `glx-projects-configuration`                 | |
| `glx-projects-issues_enabled-without-issues` | |
| `glx-projects-protected-master-branch`       | |
| `glx-projects-shared-runners`                | |
| `glx-projects-wiki`                          | |


### Configuration

You must properly [configure python-gitlab](https://python-gitlab.readthedocs.io/en/stable/cli.html#configuration)


Commands documentation
----------------------

* [gl commands](gl-commands.md)
* [glt commands](glt-commands.md)
* [glx commands](glx-commands.md)

==> gitlab-tools-v0.2.1.tar.gz: gitlab-tools/README.md <==
gitlab-tools
============

Administration tool set for **GitLab**.

Installation notes
------------------

* `pip3` is required to install `python-gitlab`: installer will try to install `python3-pip` and `python-gitlab`.
* `curl` and `jq` are required, installer will try to install then if they are missing.

To clone this repository you need to use:

```bash
git clone --recurse-submodules https://git.cclaude.rocks/tools/gitlab-tools.git
```

You migth need to install `git`. This can be done using something like:

```bash
sudo apt install -y git
```


Installation
------------

```bash
sudo -H bash ./gitlab-tools-install.sh
```

To remove, use:

```bash
sudo bash /usr/local/share/gitlab-tools/gitlab-tools-remove.sh
```

### Install options

You can get help using :

```bash
./gitlab-tools-install.sh --help
```

| Option                            | Description                   |
|-----------------------------------|-------------------------------|
| -S, --skip-update                 | To skip update before install required packets |
| -P PMEXE, --package-manager PMEXE | Force package manager binary name |

Warning:

`sudo -H` may be required by pip (python).


Tools list
----------

Raw commands based on **GitLab-Bash-API**.

| Command       | Description |
|---------------|-------------|
| `gl-delete`   | Perform a DELETE HTTP request |
| `gl-get`      | Perform a GET HTTP request |
| `gl-post`     | Perform a POST HTTP request |
| `gl-put`      | Perform a PUT HTTP request |

Basic commands based on **python-gitlab**.

| Command         | Description |
|-----------------|-------------|
| `glt-branch`    | Allow to manage and display gitlab branches. |
| `glt-group`     | Allow to manage and display gitlab groups. |
| `glt-project`   | Allow to manage and display gitlab project. |
| `glt-user`      | Allow to manage and display gitlab users. |

More specifics commands based on **GitLab-Bash-API** and **python-gitlab**.

| Command                                      | Description |
|----------------------------------------------|-------------|
| `glx-audit`                                  | Allow to make audit of your GitLab .|
| `glx-clone`                                  | Allow to `git clone` a set of projects. |
| `glx-find-wrong-remote-urls`                 | |
| `glx-projects-archived`                      | |
| `glx-projects-configuration`                 | |
| `glx-projects-issues_enabled-without-issues` | |
| `glx-projects-protected-master-branch`       | |
| `glx-projects-shared-runners`                | |
| `glx-projects-wiki`                          | |


### Configuration

You must properly [configure python-gitlab](https://python-gitlab.readthedocs.io/en/stable/cli.html#configuration)


Commands documentation
----------------------

* [gl commands](gl-commands.md)
* [glt commands](glt-commands.md)
* [glx commands](glx-commands.md)
